@@ -11,7 +11,7 @@ import re
 
 from .components import TextButton, EditDisplay, LineWalker, SimpleForm
 from .config import CONFIG_PATH, HOME
-from .messages import backup_sucess, doing_backup, welcome_url, welcome
+from .messages import backup_sucess, doing_backup, welcome_url, welcome, git_explication
 
 class GitModel:
     def __init__(self, docs_path):
